Index: media/capture/video/win/sink_input_pin_win.cc |
diff --git a/media/capture/video/win/sink_input_pin_win.cc b/media/capture/video/win/sink_input_pin_win.cc |
index e55316201d0fa4b16272a523c25aa6c27bec7d46..046300d4339850c0dff304009ae7b50a8a9b5796 100644 |
--- a/media/capture/video/win/sink_input_pin_win.cc |
+++ b/media/capture/video/win/sink_input_pin_win.cc |
@@ -14,6 +14,7 @@ |
#include "base/logging.h" |
#include "base/macros.h" |
#include "media/base/timestamp_constants.h" |
+#include "media/capture/video/video_capture_utils.h" |
namespace media { |
@@ -95,6 +96,12 @@ bool SinkInputPin::IsMediaTypeValid(const AM_MEDIA_TYPE* media_type) { |
resulting_format_.pixel_format = PIXEL_FORMAT_RGB32; |
return true; |
} |
+ if (sub_type.Data1 == pvi->bmiHeader.biCompression) { |
+ if (IsY16FormatFourCc(sub_type.Data1)) { |
+ resulting_format_.pixel_format = PIXEL_FORMAT_Y16; |
+ return true; |
+ } |
+ } |
#ifndef NDEBUG |
WCHAR guid_str[128]; |
@@ -123,8 +130,9 @@ bool SinkInputPin::GetValidMediaType(int index, AM_MEDIA_TYPE* media_type) { |
media_type->formattype = FORMAT_VideoInfo; |
media_type->bTemporalCompression = FALSE; |
- if (requested_pixel_format_ == PIXEL_FORMAT_MJPEG) { |
- // If the requested pixel format is MJPEG, accept only MJPEG. |
+ if (requested_pixel_format_ == PIXEL_FORMAT_MJPEG || |
+ requested_pixel_format_ == PIXEL_FORMAT_Y16) { |
+ // If the requested pixel format is MJPEG or Y16, don't accept other. |
// This is ok since the capabilities of the capturer have been |
// enumerated and we know that it is supported. |
if (index != 0) |